/*
*  
*  $Id: tagsprivadoscomunes.h 3963 2011-07-11 14:03:51Z tovar $
*  Ginkgo CADx Project
*
*  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
*  http://ginkgo-cadx.com
*
*  This file is licensed under LGPL v3 license.
*  See License.txt for details
*
*/
#pragma  once
//tags privados comunes a todos los diagnosticos
#define UID_TAGS_PRIVADOS_COMUNES "METAEMOTION GINKGO"

#define TAG_WIDGETS					    0xb
#define TAG_XML_INTEGRACION		    0xa

//en estos tags va la info relacionada con los informes en general
#define UID_TAGS_PRIVADOS_INFORME "METAEMOTION GINKGO DIAGNOSTIC"
#define TAG_LISTA_COMPROMISOS			 0x1
#define TAG_LISTA_COMENTARIOS			 0x2



